/**
 * AMPSNVFIXShredderSubscriber
 *
 * This sample subscribes to a topic and prints
 * NVFIX messages as they are received.
 *
 * The program flow is simple:
 *
 * - Connect to AMPS
 * - Subscribe to a topic
 * - Print the content of each NVFIX message as it is received.
 *
 * This sample doesn't include error handling, high availability, or
 * connection retry logic.
 *
 * This file is a part of the AMPS Evaluation Kit.
 *************************************************************************
 **
 ** Copyright (c) 2010-2017 60East Technologies Inc., All Rights Reserved.
 **
 ** This computer software is owned by 60East Technologies Inc. and is
 ** protected by U.S. copyright laws and other laws and by international
 ** treaties.  This computer software is furnished by 60East Technologies
 ** Inc. pursuant to a written license agreement and may be used, copied,
 ** transmitted, and stored only in accordance with the terms of such
 ** license agreement and with the inclusion of the above copyright notice.
 ** This computer software or any other copies thereof may not be provided
 ** or otherwise made available to any other person.
 **
 ** U.S. Government Restricted Rights.  This computer software: (a) was
 ** developed at private expense and is in all respects the proprietary
 ** information of 60East Technologies Inc.; (b) was not developed with
 ** government funds; (c) is a trade secret of 60East Technologies Inc.
 ** for all purposes of the Freedom of Information Act; and (d) is a
 ** commercial item and thus, pursuant to Section 12.212 of the Federal
 ** Acquisition Regulations (FAR) and DFAR Supplement Section 227.7202,
 ** Government's use, duplication or disclosure of the computer software
 ** is subject to the restrictions set forth by 60East Technologies Inc..
 **
 ************************************************************************
 **/

const amps = require('amps')


async function main() {
    const uri = 'ws://127.0.0.1:9127/amps/nvfix'
    const client = new amps.Client('ExampleNVFIXSubscriber')

    try {
        await client.connect(uri)

        // Subscribe to the NVFIX topic
        await client.subscribe(
            message => {
                // NVFIX messages are automatically converted to native JS objects
                for (let key in message.data) {
                    if (message.data.hasOwnProperty(key)) {

                        // display the values of the message
                        console.log(key, message.data[key])
                    }
                }
            },
            'messages-sow'
        )
    }
    catch (err) {
        console.error('err: ', err)
    }
}
main()
