/**
 * AMPSPublishForReplay
 *
 * This sample publishes messages to a topic in AMPS that
 * maintains a transaction log.
 *
 * The program flow is simple:
 *
 * - Connect to AMPS
 * - Logon
 * - Publish total of 1000 messages to the "messages-history" topic. Each
 *   message published has a unique orderId. The program waits one second
 *   between sets of 100 messages.
 *
 * The "messages-history" topic is configured in config/sample.xml
 * to maintain a transaction log.
 *
 * This sample doesn't include error handling, high availability, or
 * connection retry logic.
 *
 * This file is a part of the AMPS Evaluation Kit.
 *************************************************************************
 **
 ** Copyright (c) 2010-2017 60East Technologies Inc., All Rights Reserved.
 **
 ** This computer software is owned by 60East Technologies Inc. and is
 ** protected by U.S. copyright laws and other laws and by international
 ** treaties.  This computer software is furnished by 60East Technologies
 ** Inc. pursuant to a written license agreement and may be used, copied,
 ** transmitted, and stored only in accordance with the terms of such
 ** license agreement and with the inclusion of the above copyright notice.
 ** This computer software or any other copies thereof may not be provided
 ** or otherwise made available to any other person.
 **
 ** U.S. Government Restricted Rights.  This computer software: (a) was
 ** developed at private expense and is in all respects the proprietary
 ** information of 60East Technologies Inc.; (b) was not developed with
 ** government funds; (c) is a trade secret of 60East Technologies Inc.
 ** for all purposes of the Freedom of Information Act; and (d) is a
 ** commercial item and thus, pursuant to Section 12.212 of the Federal
 ** Acquisition Regulations (FAR) and DFAR Supplement Section 227.7202,
 ** Government's use, duplication or disclosure of the computer software
 ** is subject to the restrictions set forth by 60East Technologies Inc..
 **
 ************************************************************************
 **/

const amps = require('amps')


// Timer function
const sleep = seconds => new Promise(resolve => setTimeout(resolve, seconds * 1000))


// Main function
async function main() {
    const uri = 'ws://127.0.0.1:9127/amps/json'

    try {
        const client = new amps.Client('replayPublisher')
        await client.connect(uri)

        let orderId = 1
        let loopCount = 0
        while (loopCount++ < 10) {
            for (let i = 0; i < 100; ++i, ++orderId) {
                client.publish('messages-history', {
                    orderId: orderId, symbol: 'IBM', size: 1000, price: 190.01
                })
            }

            await sleep(1)
            console.log('Published', loopCount * 100, 'messages to messages-history')
        }

        await client.flush()
        await client.disconnect()
    }
    catch (err) {
        console.error('err: ', err)
    }
}
main()
