/**
 * CompositeMessagePublisher
 *
 * Simple example to demonstrate publish a composite message to a topic
 * in AMPS.
 *
 * The program flow is simple:
 *
 * - Connect to AMPS, using the transport configured for composite json-binary
 * - messages
 * - Connect and logon
 * - Construct binary data for the message. For demonstration purposes,
 * - the sample uses the same binary data for each message.
 * - Publish a set of messages to AMPS. For each message:
 *   - Construct a json part that the subscriber can filter on
 *   - Construct a composite message payload
 *   - Publish the message.
 *
 * This sample doesn't include error handling, high availability, or
 * connection retry logic.
 *
 * This file is a part of the AMPS Evaluation Kit.
 *************************************************************************
 **
 ** Copyright (c) 2010-2017 60East Technologies Inc., All Rights Reserved.
 **
 ** This computer software is owned by 60East Technologies Inc. and is
 ** protected by U.S. copyright laws and other laws and by international
 ** treaties.  This computer software is furnished by 60East Technologies
 ** Inc. pursuant to a written license agreement and may be used, copied,
 ** transmitted, and stored only in accordance with the terms of such
 ** license agreement and with the inclusion of the above copyright notice.
 ** This computer software or any other copies thereof may not be provided
 ** or otherwise made available to any other person.
 **
 ** U.S. Government Restricted Rights.  This computer software: (a) was
 ** developed at private expense and is in all respects the proprietary
 ** information of 60East Technologies Inc.; (b) was not developed with
 ** government funds; (c) is a trade secret of 60East Technologies Inc.
 ** for all purposes of the Freedom of Information Act; and (d) is a
 ** commercial item and thus, pursuant to Section 12.212 of the Federal
 ** Acquisition Regulations (FAR) and DFAR Supplement Section 227.7202,
 ** Government's use, duplication or disclosure of the computer software
 ** is subject to the restrictions set forth by 60East Technologies Inc..
 **
 ************************************************************************
 **/

const amps = require('amps')


async function main() {
    // Register the composite message type with the client
    amps.TypeHelper.helper(
        'composite-json-binary',
        amps.TypeHelper.compositeHelper('json', 'binary')
    )

    const binaryData = 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX'
    const uri = 'ws://127.0.0.1:9127/amps/composite-json-binary'
    const client = new amps.Client('CompositePublisher')

    try {
        await client.connect(uri)

        for (let i = 1; i < 10; ++i) {
            client.publish(
                'messages',        // Topic
                [                  // Composite message parts array:
                    {              // JSON part
                        number: i,
                        binarySize: binaryData.length,
                        message: 'Hello, world!'
                    },
                    binaryData     // Binary part
                ]
            )
        }

        await client.flush()
        await client.disconnect()
    }
    catch (err) {
        console.error('err: ', err)
    }
}
main()
