/**
 * CompositeMessageSubscriber
 *
 * Simple example to demonstrate subscribing to a composite message topic
 * in AMPS.
 *
 * The program flow is simple:
 *
 * - Connect to AMPS, specifying composite json-binary messages as the
 * - message type for the connection
 * - Subscribe to the topic. As each message is received:
 *   - Parse the message
 *   - Print the contents of the message
 *
 * This sample doesn't include error handling, high availability, or
 * connection retry logic.
 *
 * This file is a part of the AMPS Evaluation Kit.
 *************************************************************************
 **
 ** Copyright (c) 2010-2017 60East Technologies Inc., All Rights Reserved.
 **
 ** This computer software is owned by 60East Technologies Inc. and is
 ** protected by U.S. copyright laws and other laws and by international
 ** treaties.  This computer software is furnished by 60East Technologies
 ** Inc. pursuant to a written license agreement and may be used, copied,
 ** transmitted, and stored only in accordance with the terms of such
 ** license agreement and with the inclusion of the above copyright notice.
 ** This computer software or any other copies thereof may not be provided
 ** or otherwise made available to any other person.
 **
 ** U.S. Government Restricted Rights.  This computer software: (a) was
 ** developed at private expense and is in all respects the proprietary
 ** information of 60East Technologies Inc.; (b) was not developed with
 ** government funds; (c) is a trade secret of 60East Technologies Inc.
 ** for all purposes of the Freedom of Information Act; and (d) is a
 ** commercial item and thus, pursuant to Section 12.212 of the Federal
 ** Acquisition Regulations (FAR) and DFAR Supplement Section 227.7202,
 ** Government's use, duplication or disclosure of the computer software
 ** is subject to the restrictions set forth by 60East Technologies Inc..
 **
 ************************************************************************
 **/

const amps = require('amps')

// Register the composite message type with the client
amps.TypeHelper.helper(
    'composite-json-binary',
    amps.TypeHelper.compositeHelper('json', 'binary')
)


async function main() {
    const uri = 'ws://127.0.0.1:9127/amps/composite-json-binary'
    const client = new amps.Client('CompositeSubscriber')

    try {
        await client.connect(uri)

        // Subscribe and process messages
        await client.subscribe(
            message => {
                if (message.data.length !== 2) {
                    return console.error('Unknown message type')
                }

                // Get the contents of the message
                const jsonPart = message.data[0]
                const binaryPart = message.data[1]

                // Print the message
                console.log('Received message with', message.data.length, 'parts')
                console.log(jsonPart)
                console.log(binaryPart)
            },
            'messages',
            '/0/number % 3 == 0'
        )
    }
    catch (err) {
        console.error('err: ', err)
    }
}
main()
